desc 'Prepares basic gem project structure and configuration.'
task :prepare_gem_project do |t, args|
  require 'fileutils'
  require 'uu_os_cmd/version'
  require 'uu/os/util/name_converter'

  basename = File.basename(Dir.pwd).split('-')[0].downcase

  puts "Creating gem project structure"
  lib_dir = File.join(Dir.pwd, 'lib')
  Dir.mkdir(lib_dir) unless File.directory?(lib_dir)
  test_dir = File.join(Dir.pwd, 'test')
  Dir.mkdir(test_dir) unless File.directory?(test_dir)
  mod_dir =  File.join(lib_dir, basename)
  FileUtils.mkdir_p(mod_dir)

  puts "Creating gem configuration files"
  gemspec = File.join(Dir.pwd, "#{basename}.gemspec")
  if !File.exists?(gemspec)
    out = File.open(gemspec, 'w+')
    out.write("$:.push File.expand_path('../lib', __FILE__)\n")
    out.write("require '#{basename}/version'\n")
    out.write("Gem::Specification.new do |s|\n")
    out.write("  s.name          = '#{basename}'\n")
    out.write("  s.version       = #{UU::OS::Util::NameConverter.to_upper_camel_case(basename)}::VERSION\n")
    out.write("  s.require_paths = ['lib']\n")
    out.write("  s.files         = Dir['lib/**/*.*']\n")
    out.write("  # TODO Update summary and author attributes:\n")
    out.write("  s.summary       = '#{basename}'\n")
    out.write("  s.author        = '#{basename.split('_')[0].upcase}'\n")
    out.write("  # TODO Fill in following attributes:\n")
    out.write("  # s.summary       = '< short description >'\n")
    out.write("  # s.description   = '< description >'\n")
    out.write("  # s.author        = '< vendor name >'\n")
    out.write("  # s.homepage      = '< vendor homepage >'\n")
    out.write("  # s.email         = '< vendor e-mail >'\n")
    out.write("  # s.license       = '< library licence >'\n\n")
    out.write("  s.add_dependency('uu_os_cmd', '~>#{UUOSCMD::VERSION.split('.')[0..1].join('.')}')\n")
    out.write("  s.add_dependency('uu_os_framework', '~>0.13')\n")
    out.write("  # Thirdparty dependencies...\n")
    out.write("  # s.add_dependency('< gem name >', '~>< gem version >')\n\n")
    out.write("end;\n")
    out.close
  end
  reqfile = File.join(lib_dir, "#{basename}.rb")
  if !File.exists?(reqfile)
    out = File.open(reqfile, 'w+')
    out.write("# Require all gem scripts by their relative names:\n")
    out.write("Dir[File.dirname(__FILE__) + '/#{basename}/**/*.rb'].each do |file|\n")
    out.write("  require file.gsub('\\\\','/').split('/lib/').last[0..-4]\n")
    out.write("end\n")
    out.close
  end

  puts "Creating gem version file"
  version = File.join(Dir.pwd, 'lib', basename, 'version.rb')
  FileUtils.mkdir_p(File.dirname(version))
  if !File.exists?(version)
    out = File.open(version, 'w+')
    out.write("module #{UU::OS::Util::NameConverter.to_upper_camel_case(basename)}\n")
    out.write("  VERSION = '0.0.1'\n")
    out.write("end\n")
    out.close
  end

end
